@@ -82,7 +82,7 @@ class DataModel():
                 data['c'] = col
                 data['v'] = self._get_attr_value(item, col)
             json_data.append(data)
-        return [{'cols': json_cols, 'data': json_data}]
+        return [{'cols': json_cols, 'rows': json_data}]
 
 
 class SQLAModel(DataModel):
@@ -164,7 +164,6 @@ class SQLAModel(DataModel):
         query = self.session.query(self.obj)
         query = self._get_base_query(query=query, filters=filters)
         query_result = query.all()
-        #query_result = sorted(query_result, key=lambda item: getattr(item, group_by))
         group = GroupByCol(group_by, 'Group by')
         return group.apply(query_result)
 
