@@ -4,8 +4,10 @@ Created on Oct 12, 2013
 @author: Daniel Gaspar
 '''
 
+import logging
 from flask.globals import _request_ctx_stack
 
+log = logging.getLogger(__name__)
 
 class RenderTemplateWidget(object):
 
@@ -18,7 +20,7 @@ class RenderTemplateWidget(object):
     def __call__(self, **kwargs):
         ctx = _request_ctx_stack.top
         jinja_env = ctx.app.jinja_env
-
+        
         template = jinja_env.get_template(self.template)
         args = dict(self.template_args.items() + kwargs.items())
         return template.render(args)
@@ -35,6 +37,9 @@ class FormWidget(RenderTemplateWidget):
     """
     template = 'appbuilder/general/widgets/form.html'
 
+class GroupFormListWidget(RenderTemplateWidget):
+    template = 'appbuilder/general/widgets/group_form_list.html'    
+
 
 class SearchWidget(FormWidget):
     template = 'appbuilder/general/widgets/search.html'
